@@ -1,13 +1,14 @@
-URL_PREFIX = "https://www."
+URL_PREFIX = "https://"
 
 
 class href:
-    def __init__(self, string, origin) -> None:
+    def __init__(self, string, origin, subdomain) -> None:
         self.content = string
         self.origin = origin
+        self.subdomain = subdomain
     
     def url(self): 
-        url = URL_PREFIX + self.origin + self.content
+        url = self.subdomain + self.origin + self.content
         try:
             scheme = self.content.split(":")[0]
             if scheme == "https": return self.content
